==> karot_components-0.0.1.tar.gz: lib/constant/button_style.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/theme.dart';

class BStyle {
  BStyle._();

  static ButtonStyle buttonStyle(
      {int? backgroundColor,
      KRButtonSize size = KRButtonSize.regular,
      bool isFull = false,
      bool isOutline = false}) {
    return ButtonStyle(
        overlayColor: MaterialStateColor.resolveWith(
            (states) => const Color(KRTheme.DEFAULT_PRIMARY_OVERLAY_COLOR)),
        minimumSize: isFull
            ? MaterialStateProperty.all<Size>(Size.fromHeight(size.heightSize))
            : null,
        padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.only(
            left: size.paddingSide,
            right: size.paddingSide,
            top: size.paddingTopBottom,
            bottom: size.paddingTopBottom)),
        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: isOutline
                    ? const BorderSide(
                        color: Color(KRTheme.DEFAULT_PRIMARY_COLOR), width: 1.5)
                    : BorderSide.none)),
        backgroundColor: isOutline
            ? null
            : KRColor(
                defaultColor: backgroundColor ?? KRTheme.DEFAULT_PRIMARY_COLOR, pressedColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR));
  }

  static ButtonStyle textButtonStyle(
      {KRButtonSize size = KRButtonSize.regular,
      bool isFull = false,
      bool isOutline = false}) {
    return ButtonStyle(
        overlayColor: MaterialStateColor.resolveWith(
            (states) => const Color(KRTheme.DEFAULT_PRIMARY_OVERLAY_COLOR)),
        padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.only(
            left: size.paddingSide,
            right: size.paddingSide,
            top: size.paddingTopBottom,
            bottom: size.paddingTopBottom)));
  }
}

==> karot_components-0.0.2.tar.gz: lib/constant/button_style.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/theme.dart';

class BStyle {
  BStyle._();

  static ButtonStyle buttonStyle(
      {int? backgroundColor,
      KRButtonSize size = KRButtonSize.regular,
      bool isFull = false,
      bool isOutline = false}) {
    return ButtonStyle(
        overlayColor: MaterialStateColor.resolveWith(
            (states) => const Color(KRTheme.DEFAULT_PRIMARY_OVERLAY_COLOR)),
        minimumSize: isFull
            ? MaterialStateProperty.all<Size>(Size.fromHeight(size.heightSize))
            : null,
        padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.only(
            left: size.paddingSide,
            right: size.paddingSide,
            top: size.paddingTopBottom,
            bottom: size.paddingTopBottom)),
        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: isOutline
                    ? const BorderSide(
                        color: Color(KRTheme.DEFAULT_PRIMARY_COLOR), width: 1.5)
                    : BorderSide.none)),
        backgroundColor: isOutline
            ? null
            : KRColor(
                defaultColor: backgroundColor ?? KRTheme.DEFAULT_PRIMARY_COLOR,
                pressedColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR));
  }

  static ButtonStyle iconButtonStyle(
      {int? backgroundColor,
      KRButtonSize size = KRButtonSize.regular,
      bool isOutline = false}) {
    return ButtonStyle(
        minimumSize:
            MaterialStateProperty.all<Size>(Size.square(size.squerySize)),
        overlayColor: MaterialStateColor.resolveWith(
            (states) => const Color(KRTheme.DEFAULT_PRIMARY_OVERLAY_COLOR)),
        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(50.0),
                side: isOutline
                    ? const BorderSide(
                        color: Color(KRTheme.DEFAULT_PRIMARY_COLOR), width: 1.5)
                    : BorderSide.none)),
        backgroundColor: isOutline
            ? null
            : KRColor(
                defaultColor: backgroundColor ?? KRTheme.DEFAULT_CLEAR_COLOR,
                pressedColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR));
  }

  static ButtonStyle textButtonStyle() {
    return ButtonStyle(
        overlayColor: MaterialStateColor.resolveWith(
            (states) => const Color(KRTheme.DEFAULT_PRIMARY_OVERLAY_COLOR)));
  }
}
